package com.hys.app.controller.erp.use;

import com.hys.app.framework.context.user.AdminUserContext;
import com.hys.app.framework.database.WebPage;
import com.hys.app.model.erp.dos.WarehouseEntryDO;
import com.hys.app.model.erp.dto.WarehouseEntryDTO;
import com.hys.app.model.erp.dto.WarehouseEntryQueryParams;
import com.hys.app.model.erp.dto.WarehouseEntryStatisticsParam;
import com.hys.app.model.erp.enums.WarehouseEntryStatusEnum;
import com.hys.app.model.erp.vo.WarehouseAreaVO;
import com.hys.app.model.erp.vo.WarehouseEntryVO;
import com.hys.app.model.support.LogClient;
import com.hys.app.model.support.validator.annotation.Log;
import com.hys.app.service.erp.WarehouseAreaManager;
import com.hys.app.service.erp.WarehouseEntryManager;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.Objects;

/**
 * 入库单相关API
 *
 * @author 张崧
 * @since 2023-12-05 11:25:07
 */
@RestController
@RequestMapping("/admin/erp/warehouseEntry")
@Api(tags = "入库单相关API")
@Validated
public class WarehouseEntryManagerController {

    @Autowired
    private WarehouseEntryManager warehouseEntryManager;


    @ApiOperation(value = "分页列表")
    @GetMapping
    public WebPage<WarehouseEntryDO> list(WarehouseEntryQueryParams queryParams) {
        return warehouseEntryManager.list(queryParams);
    }

    @ApiOperation(value = "添加")
    @PostMapping
    @Log(client = LogClient.admin, detail = "创建入库单")
    public Long add(@RequestBody @Valid WarehouseEntryDTO warehouseEntryDTO) {
        AdminUserContext.hasCompany();
        return warehouseEntryManager.add(warehouseEntryDTO);
    }

    @ApiOperation(value = "修改")
    @PutMapping("/{id}")
    @Log(client = LogClient.admin, detail = "编辑ID为[${id}]的入库单")
    public void edit(@PathVariable Long id, @RequestBody @Valid WarehouseEntryDTO warehouseEntryDTO) {
        warehouseEntryManager.edit(warehouseEntryDTO,id);
    }

    @ApiOperation(value = "查询")
    @GetMapping("/{id}")
    public WarehouseEntryVO getDetail(@PathVariable Long id) {
        return warehouseEntryManager.getDetail(id);
    }

    @ApiOperation(value = "删除")
    @DeleteMapping("/{id}")
    @Log(client = LogClient.admin, detail = "删除ID为[${ids}]的入库单")
    public void delete(@PathVariable Long id) {
        warehouseEntryManager.delete(id);
    }

    @ApiOperation(value = "导出入库单统计列表数据")
    @GetMapping("/export")
    public void export(HttpServletResponse response, WarehouseEntryStatisticsParam params) {
        this.warehouseEntryManager.export(response, params);
    }
}

